Open Peer Power |Chat Status|
=================================================================================

Open source home automation that puts local control and privacy first. Powered by a worldwide community of tinkerers and DIY enthusiasts. Perfect to run on a Raspberry Pi or a local server.

Check out `openpeerpower.io <https://openpeerpower.io>`__ for `a
demo <https://openpeerpower.io/demo/>`__, `installation instructions <https://openpeerpower.io/getting-started/>`__,
`tutorials <https://openpeerpower.io/getting-started/automation/>`__ and `documentation <https://openpeerpower.io/docs/>`__.

|screenshot-states|

Featured integrations
---------------------

|screenshot-components|

The system is built using a modular approach so support for other devices or actions can be implemented easily. See also the `section on architecture <https://developers.openpeerpower.io/docs/architecture_index/>`__ and the `section on creating your own
components <https://developers.openpeerpower.io/docs/creating_component_index/>`__.

If you run into issues while using Open Peer Power or during development
of a component, check the `Open Peer Power help section <https://openpeerpower.io/help/>`__ of our website for further help and information.

.. |Chat Status| image:: https://img.shields.io/discord/330944238910963714.svg
   :target: https://discord.gg/c5DvZ4e
.. |screenshot-states| image:: https://raw.github.com/openpeerpower/openpeerpower/master/docs/screenshots.png
   :target: https://openpeerpower.io/demo/
.. |screenshot-components| image:: https://raw.github.com/openpeerpower/openpeerpower/dev/docs/screenshot-components.png
   :target: https://openpeerpower.io/integrations/
